# Changelog

## [0.4.0](https://github.com/acdh-oeaw/django-invitelink/compare/v0.3.0...v0.4.0) (2025-12-23)


### Features

* **templates:** let invite.html fall back to d-il's base template ([16c0960](https://github.com/acdh-oeaw/django-invitelink/commit/16c096088e2ff2c5104b0b29f1ea0905fd17f8f0))
* **templates:** move `invite.html` to `django_invitelink` directory ([34847be](https://github.com/acdh-oeaw/django-invitelink/commit/34847be97fde83fa4049b262bef27bc52d301432))
* **templates:** ship base template ([1f26ba9](https://github.com/acdh-oeaw/django-invitelink/commit/1f26ba9b9e0274559d52e62744c0f3ca55d10ed4))

## [0.3.0](https://github.com/acdh-oeaw/django-invitelink/compare/v0.2.0...v0.3.0) (2025-12-23)


### Miscellaneous Chores

* release 0.3.0 ([676bd6c](https://github.com/acdh-oeaw/django-invitelink/commit/676bd6cef014265d49ae802cc407d5a9946e5d06))

## [0.2.0](https://github.com/acdh-oeaw/apis-acdhch-django-invite/compare/v0.1.1...v0.2.0) (2024-12-03)


### Features

* add consume_invite signal ([02699fd](https://github.com/acdh-oeaw/apis-acdhch-django-invite/commit/02699fd76143d8b7af6a9943e7682bc332a60ebb)), closes [#5](https://github.com/acdh-oeaw/apis-acdhch-django-invite/issues/5)


### Bug Fixes

* **deps:** loosen apis-core-rdf dependency version ([d856171](https://github.com/acdh-oeaw/apis-acdhch-django-invite/commit/d856171a3dbf5a4566d76018d93bc0036262d4b8)), closes [#4](https://github.com/acdh-oeaw/apis-acdhch-django-invite/issues/4)

## [0.1.1](https://github.com/acdh-oeaw/apis-acdhch-django-invite/compare/v0.1.0...v0.1.1) (2024-12-03)


### Bug Fixes

* add missing __init__ file ([e91b8de](https://github.com/acdh-oeaw/apis-acdhch-django-invite/commit/e91b8dee10963b19177a62ec42ea2ecdcc63c727))

## 0.1.0 (2024-12-02)


### Documentation

* add README ([679d0a6](https://github.com/acdh-oeaw/apis-acdhch-django-invite/commit/679d0a66feb4b9deb4fd715203cd433409a56738))
